# This file was auto-generated by zetup
#
# https://bitbucket.org/userzimmermann/zetup.py


from __future__ import absolute_import

import sys
import os
from collections import OrderedDict

from zetup.version import Version
from zetup.dist import Distribution
from zetup.requires import Requirements
from zetup.extras import Extras
from zetup.package import Packages, Package
from zetup.notebook import Notebook



zfg = sys.modules[__name__]

LICENSE = 'LGPLv3'

TITLE = 'jinjatools'

PYTHON = ['2.7', '3.3', '3.4']

MODULES = []

KEYWORDS = ['jinja', 'jinja2', 'tools', 'template', 'macro', 'filter', 'test', 'moretools', 'scons', 'builder', 'build', 'django', 'web', 'html', 'python3']

PACKAGES = Packages([

Package('jinjatools',
  sources=[
    'env.py',
    '__init__.py',
    'ext.py',
    'filters.py'
    ],
  subpackages=[
    
Package('jinjatools.django',
  sources=[
    '__init__.py'
    ],
  subpackages=[
    
    ],
  )
,
    
Package('jinjatools.scons',
  sources=[
    '__init__.py'
    ],
  subpackages=[
    
    ],
  )

    ],
  )

  ], root=os.path.dirname(os.path.dirname(os.path.realpath(__file__))))

EMAIL = 'zimmermann.code@gmail.com'

AUTHOR = 'Stefan Zimmermann'

REQUIRES = Requirements("""
six >= 1.9
path.py >= 7.5 #import path
moretools >= 0.1.7
Jinja2 #import jinja2
zetup >= 0.2.16

""", zfg=zfg)

URL = 'http://bitbucket.org/userzimmermann/python-jinjatools'

SETUP_HOOKS = []

VERSION = Version('0.1.6')

NAME = 'jinjatools'

DESCRIPTION = 'Various tools for Jinja2, including new filters and tests based on moretools, a JinjaLoader class for Django, and a simple JinjaBuilder class for SCons.'

SETUP_REQUIRES = None

EXTRAS = Extras([

], zfg=zfg)

DISTRIBUTION = Distribution('jinjatools', 'jinjatools', '0.1.6')

CLASSIFIERS = ['Development Status :: 3 - Alpha', 'Intended Audience :: Developers', 'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)', 'Operating System :: OS Independent', 'Programming Language :: Python', 'Programming Language :: Python :: 2', 'Programming Language :: Python :: 3', 'Topic :: Software Development', 'Topic :: Utilities', 'Programming Language :: Python', 'Programming Language :: Python :: 2.7', 'Programming Language :: Python :: 3.3', 'Programming Language :: Python :: 3.4']